# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class AyScatter(Component):
    """An AyScatter component.
An Ant Chart component
See https://ant-design-charts.antgroup.com/examples/statistics/pie/#outer-label

Keyword arguments:

- id (string; optional):
    ID.

- data (list of dicts; optional):
    Data.

- groupbyField (string; optional):
    Group by fied.

- height (string | number; optional):
    Height.

- legend (boolean | dict | string; optional):
    Whether to show legend.

- showGrid (boolean; default True):
    Whether to show grid.

- showRegression (boolean; default True):
    Whether to show regression lines.

- xField (string; default 'x'):
    X Field (Catgories).

- xFieldTitle (string; optional):
    X Axis Title.

- yField (string; default 'y'):
    Y Field (value).

- yFieldTitle (string; optional):
    Y Axis Title."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'ay_charts'
    _type = 'AyScatter'
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, data=Component.UNDEFINED, xField=Component.UNDEFINED, yField=Component.UNDEFINED, groupbyField=Component.UNDEFINED, legend=Component.UNDEFINED, height=Component.UNDEFINED, showGrid=Component.UNDEFINED, showRegression=Component.UNDEFINED, xFieldTitle=Component.UNDEFINED, yFieldTitle=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'data', 'groupbyField', 'height', 'legend', 'showGrid', 'showRegression', 'xField', 'xFieldTitle', 'yField', 'yFieldTitle']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'data', 'groupbyField', 'height', 'legend', 'showGrid', 'showRegression', 'xField', 'xFieldTitle', 'yField', 'yFieldTitle']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(AyScatter, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class AyPie(Component):
    """An AyPie component.
An Ant Chart component
See https://ant-design-charts.antgroup.com/examples/statistics/pie/#outer-label

Keyword arguments:

- id (string; optional):
    ID.

- data (list of dicts; optional):
    Data.

- donut (boolean; default False):
    If the pie is a donut.

- height (string | number; optional):
    Height.

- legend (boolean | dict | string; optional):
    Whether to show legend.

- showLabel (boolean; default True):
    Whether to show label.

- tooltipName (string; default 'No. of Subjects'):
    Name of tooltip.

- xField (string; default 'name'):
    X Field (Catgories).

- yField (string; default 'value'):
    Y Field (value)."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'ay_charts'
    _type = 'AyPie'
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, data=Component.UNDEFINED, xField=Component.UNDEFINED, yField=Component.UNDEFINED, legend=Component.UNDEFINED, showLabel=Component.UNDEFINED, tooltipName=Component.UNDEFINED, height=Component.UNDEFINED, donut=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'data', 'donut', 'height', 'legend', 'showLabel', 'tooltipName', 'xField', 'yField']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'data', 'donut', 'height', 'legend', 'showLabel', 'tooltipName', 'xField', 'yField']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(AyPie, self).__init__(**args)



from .AyBar import AyBar
from .AyBox import AyBox
from .AyCard import AyCard
from .AyChart import AyChart
from .AyColumn import AyColumn
from .AyCorr import AyCorr
from .AyHistogram import AyHistogram
from .AyPie import AyPie
from .AyScatter import AyScatter

__all__ = [
    "AyBar",
    "AyBox",
    "AyCard",
    "AyChart",
    "AyColumn",
    "AyCorr",
    "AyHistogram",
    "AyPie",
    "AyScatter"
]


# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class AyChart(Component):
    """An AyChart component.
A chart wrapper based on the Ant Design card component
See https://ant.design/components/card

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    Content to be displayed on the tag.

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- axis (boolean | dict; optional):
    Whether to show axis (applies to boxes).

- backgroundColor (string; default '#fff'):
    Background color.

- border (boolean; optional):
    Border.

- box (boolean; default False):
    Whether to show box.

- chart (a value equal to: 'bar', 'box', 'histogram', 'pie', 'corr', 'scatter'; optional):
    Type of chart.

- colorField (string; optional):
    Color Field (applies to correlation matrix only).

- data (list of dicts; optional):
    Data.

- direction (a value equal to: 'vertical', 'horizontal'; default 'horizontal'):
    Direction of chart (applies to bars only).

- grid (boolean; default True):
    Whether to show grid.

- groupbyField (string; optional):
    Group by/Stratified field.

- height (string | number; optional):
    Height.

- isCard (boolean; default False):
    Whether to wrap the chart in a card.

- isDonut (boolean; default False):
    Whether the pie is a donut.

- label (boolean; optional):
    Label.

- legend (a value equal to: true, false, 'top', 'right'; optional):
    Legend setting.

- nBins (number; default 10):
    No. of bins (applies to histograms only).

- normalize (boolean; default False):
    Wether to normalize/show percentages (applies to bars only).

- raw (boolean; default False):
    Whether the data is raw (applies to boxes only).

- regression (boolean; default True):
    Whether to show regression lines (applies to scatter plot only).

- stack (boolean; optional):
    Whether to stack groups.

- title (a list of or a singular dash component, string or number; optional):
    Title.

- tooltipName (string; optional):
    Name of tooltip.

- width (string | number; default '100%'):
    Width.

- xField (string; optional):
    X Field (Catgories).

- xFieldTitle (string; optional):
    X Axis Title.

- yField (string; optional):
    Y Field (value).

- yFieldTitle (string; optional):
    Y Axis Title."""
    _children_props = ['title']
    _base_nodes = ['title', 'children']
    _namespace = 'ay_charts'
    _type = 'AyChart'
    @_explicitize_args
    def __init__(self, children=None, data=Component.UNDEFINED, xField=Component.UNDEFINED, yField=Component.UNDEFINED, groupbyField=Component.UNDEFINED, colorField=Component.UNDEFINED, stack=Component.UNDEFINED, nBins=Component.UNDEFINED, normalize=Component.UNDEFINED, chart=Component.UNDEFINED, direction=Component.UNDEFINED, legend=Component.UNDEFINED, axis=Component.UNDEFINED, xFieldTitle=Component.UNDEFINED, yFieldTitle=Component.UNDEFINED, label=Component.UNDEFINED, box=Component.UNDEFINED, raw=Component.UNDEFINED, isDonut=Component.UNDEFINED, id=Component.UNDEFINED, title=Component.UNDEFINED, tooltipName=Component.UNDEFINED, height=Component.UNDEFINED, width=Component.UNDEFINED, border=Component.UNDEFINED, backgroundColor=Component.UNDEFINED, isCard=Component.UNDEFINED, grid=Component.UNDEFINED, regression=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'axis', 'backgroundColor', 'border', 'box', 'chart', 'colorField', 'data', 'direction', 'grid', 'groupbyField', 'height', 'isCard', 'isDonut', 'label', 'legend', 'nBins', 'normalize', 'raw', 'regression', 'stack', 'title', 'tooltipName', 'width', 'xField', 'xFieldTitle', 'yField', 'yFieldTitle']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'axis', 'backgroundColor', 'border', 'box', 'chart', 'colorField', 'data', 'direction', 'grid', 'groupbyField', 'height', 'isCard', 'isDonut', 'label', 'legend', 'nBins', 'normalize', 'raw', 'regression', 'stack', 'title', 'tooltipName', 'width', 'xField', 'xFieldTitle', 'yField', 'yFieldTitle']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(AyChart, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class AyBar(Component):
    """An AyBar component.
An Ant Chart component
See https://ant-design-charts.antgroup.com/en/examples/statistics/bar/#bar

Keyword arguments:

- id (string; optional):
    ID.

- data (list of dicts; default [    {        label: 'Blue',        value: 110,    },    {        label: 'White',        value: 220,    },    {        label: 'Pink',        value: 330,    },    {        label: 'Green',        value: 440,    },]):
    Data.

- groupbyField (string; optional):
    Group by/Stratified field.

- height (string | number; optional):
    Height.

- legend (boolean | dict; optional):
    Whether to show legend.

- normalize (boolean; default False):
    Wether to normalize/show percentages.

- showGrid (boolean; default True):
    Whether to show grid.

- showLabel (boolean; default False):
    Whether to show label.

- stack (boolean; default True):
    Whether to stack groups.

- tooltipName (string; default 'No. of Subjects'):
    Name of tooltip.

- width (string | number; optional):
    Width.

- xField (string; default 'label'):
    X Field (Catgories).

- xFieldTitle (string; optional):
    X Axis Title.

- yField (string; default 'value'):
    Y Field (value).

- yFieldTitle (string; optional):
    Y Axis Title."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'ay_charts'
    _type = 'AyBar'
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, data=Component.UNDEFINED, xField=Component.UNDEFINED, yField=Component.UNDEFINED, groupbyField=Component.UNDEFINED, normalize=Component.UNDEFINED, tooltipName=Component.UNDEFINED, showLabel=Component.UNDEFINED, legend=Component.UNDEFINED, xFieldTitle=Component.UNDEFINED, yFieldTitle=Component.UNDEFINED, stack=Component.UNDEFINED, height=Component.UNDEFINED, width=Component.UNDEFINED, showGrid=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'data', 'groupbyField', 'height', 'legend', 'normalize', 'showGrid', 'showLabel', 'stack', 'tooltipName', 'width', 'xField', 'xFieldTitle', 'yField', 'yFieldTitle']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'data', 'groupbyField', 'height', 'legend', 'normalize', 'showGrid', 'showLabel', 'stack', 'tooltipName', 'width', 'xField', 'xFieldTitle', 'yField', 'yFieldTitle']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(AyBar, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class AyHistogram(Component):
    """An AyHistogram component.
An Ant Chart component
See https://ant-design-charts.antgroup.com/en/examples/statistics/bar/#bar

Keyword arguments:

- id (string; optional):
    ID.

- binField (string; default 'value'):
    Bin Field (value).

- binFieldTitle (string; optional):
    X Axis Title.

- data (list of dicts; default [    {value: 12.0},    {value: 12.9},    {value: 12.9},    {value: 13.3},    {value: 13.7},    {value: 13.8},    {value: 13.9},    {value: 14.0},    {value: 14.2},    {value: 14.5},    {value: 15},    {value: 15.2},    {value: 15.6},    {value: 16.0},    {value: 16.3},    {value: 17.3},    {value: 17.5},    {value: 17.9},    {value: 18.0},    {value: 18.0},    {value: 20.6},    {value: 21},    {value: 23.4},]):
    Data.

- groupbyField (string; optional):
    Group by/Stratified field.

- height (string | number; optional):
    Height.

- legend (boolean | dict; optional):
    Whether to show legend.

- nBins (number; default 10):
    No. of bins.

- normalize (boolean; default False):
    Wether to normalize/show percentages.

- showAxis (boolean; default True):
    Whether to show axis.

- showGrid (boolean; default True):
    Whether to show grid.

- stack (boolean; default True):
    Whether to stack groups.

- tooltipName (string; optional):
    Name of tooltip.

- valueFieldTitle (string; optional):
    Y Axis Title."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'ay_charts'
    _type = 'AyHistogram'
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, data=Component.UNDEFINED, binField=Component.UNDEFINED, nBins=Component.UNDEFINED, groupbyField=Component.UNDEFINED, normalize=Component.UNDEFINED, tooltipName=Component.UNDEFINED, legend=Component.UNDEFINED, binFieldTitle=Component.UNDEFINED, valueFieldTitle=Component.UNDEFINED, showAxis=Component.UNDEFINED, stack=Component.UNDEFINED, height=Component.UNDEFINED, showGrid=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'binField', 'binFieldTitle', 'data', 'groupbyField', 'height', 'legend', 'nBins', 'normalize', 'showAxis', 'showGrid', 'stack', 'tooltipName', 'valueFieldTitle']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'binField', 'binFieldTitle', 'data', 'groupbyField', 'height', 'legend', 'nBins', 'normalize', 'showAxis', 'showGrid', 'stack', 'tooltipName', 'valueFieldTitle']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(AyHistogram, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class AyCard(Component):
    """An AyCard component.
A chart wrapper based on the Ant Design card component
See https://ant.design/components/card

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    Content to be displayed on the tag.

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- backgroundColor (string; default '#fff'):
    Background color.

- border (boolean; optional):
    Border.

- height (string | number; optional):
    Height.

- title (a list of or a singular dash component, string or number; optional):
    Title.

- width (string | number; default '100%'):
    Width."""
    _children_props = ['title']
    _base_nodes = ['title', 'children']
    _namespace = 'ay_charts'
    _type = 'AyCard'
    @_explicitize_args
    def __init__(self, children=None, title=Component.UNDEFINED, id=Component.UNDEFINED, height=Component.UNDEFINED, width=Component.UNDEFINED, border=Component.UNDEFINED, backgroundColor=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'backgroundColor', 'border', 'height', 'title', 'width']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'backgroundColor', 'border', 'height', 'title', 'width']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(AyCard, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class AyCorr(Component):
    """An AyCorr component.
An Ant Chart component
See https://ant-design-charts.antgroup.com/examples/statistics/heatmap/#cell-aggregated

Keyword arguments:

- id (string; optional):
    ID.

- colorField (string; default 'value'):
    Color Field (value).

- data (list of dicts; default [    {        x: 'A',        y: 'B',        value: -0.66,        p: 0.03,    },    {        x: 'A',        y: 'D',        value: 0.04,        p: 0.5,    },    {        x: 'A',        y: 'E',        value: 0.04,        p: 0.9,    },    {        x: 'A',        y: 'C',        value: 0.1,        p: 0.2,    },    {        x: 'C',        y: 'B',        value: 0.08,        p: 0.05,    },    {        x: 'C',        y: 'D',        value: 0.15,        p: 0.01,    },    {        x: 'C',        y: 'E',        value: 0.39,        p: 0.1,    },    {        x: 'C',        y: 'A',        value: 0.1,        p: 0.01,    },    {        x: 'E',        y: 'B',        value: 0.09,        p: 0.01,    },    {        x: 'E',        y: 'D',        value: 0.24,        p: 0.5,    },]):
    Data.

- height (string | number; optional):
    Height.

- legend (boolean | dict | string; optional):
    Whether to show legend.

- legend_title (string; default 'r'):
    Legend title.

- showGrid (boolean; default True):
    Whether to show grid.

- showLabel (boolean; default True):
    Whether to show label.

- step (number; default 0.01):
    Step.

- xField (string; default 'x'):
    X Field (Catgories).

- yField (string; default 'y'):
    Y Field (value)."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'ay_charts'
    _type = 'AyCorr'
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, data=Component.UNDEFINED, xField=Component.UNDEFINED, yField=Component.UNDEFINED, colorField=Component.UNDEFINED, legend=Component.UNDEFINED, showLabel=Component.UNDEFINED, height=Component.UNDEFINED, step=Component.UNDEFINED, legend_title=Component.UNDEFINED, showGrid=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'colorField', 'data', 'height', 'legend', 'legend_title', 'showGrid', 'showLabel', 'step', 'xField', 'yField']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'colorField', 'data', 'height', 'legend', 'legend_title', 'showGrid', 'showLabel', 'step', 'xField', 'yField']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(AyCorr, self).__init__(**args)
